Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Adwaita ¶
type Adwaita struct{}
Adwaita is a theme that follows the Adwaita theme. It provides a light and dark theme + icons. See: https://gnome.pages.gitlab.gnome.org/libadwaita/doc/main/named-colors.html
func (*Adwaita) Color ¶
func (a *Adwaita) Color(name fyne.ThemeColorName, variant fyne.ThemeVariant) color.Color
Color returns the named color for the current theme.
Click to show internal directories.
Click to hide internal directories.